<?php
/**
 * {TABLE_CLASS_NAME}ơ֥륯饹
 *
 * @access    public
 * @package   {PROJECT_NAME}
 * @author    {author}
 * @version   $Id: Table.php,v 1.2 2007/09/29 09:10:39 seasonstream Exp $
 */
class {TABLE_CLASS_NAME} extends SyL_DBDaoTable
{
/**
 * ơ֥̾
 * 
 * @access protected
 * @var string
 */
var $table = '{TABLE_NAME}';
/**
 * ץ饤ޥꥭ
 * 
 * @access protected
 * @var array
 */
var $primary = {TABLE_PRIMARY};
/**
 * ե
 * 
 * @access protected
 * @var array
 */
var $uniques = {TABLE_UNIQUES};
/**
 * 
 * 
 * @access protected
 * @var array
 */
var $foreigns = {TABLE_FOREIGNS};
/**
 * 
 * 
 * @access protected
 * @var array
 */
var $columns = {TABLE_COLUMNS};

}

?>
